# geolog


[![image](https://img.shields.io/pypi/v/geolog.svg)](https://pypi.python.org/pypi/geolog)
[![image](https://img.shields.io/conda/vn/conda-forge/geolog.svg)](https://anaconda.org/conda-forge/geolog)


**My senior year GEOG 510 project. I will do something with this at some point.**


-   Free software: MIT license
-   Documentation: https://whitson-buck.github.io/geolog
    

## Features

-   TODO

## Credits

This package was created with [Cookiecutter](https://github.com/cookiecutter/cookiecutter) and the [giswqs/pypackage](https://github.com/giswqs/pypackage) project template.
